pub enum SaveOutput {
File(PathBuf),
Stream(Box<dyn SaveStream>),
Drop,
// some variants omitted
}Expand description
Output of the save process.
Variants
File(PathBuf)
Save into a file at the given path.
Stream(Box<dyn SaveStream>)
Save into a Write stream.
Drop
Drops the save data.
This is useful if you would like to process the Saved data manually.
You can observe the [OnSave] event for post-processing logic.
Implementations
Sourceimpl SaveOutput
impl SaveOutput
Sourcepub fn file(path: impl Into<PathBuf>) -> Self
pub fn file(path: impl Into<PathBuf>) -> Self
Creates a new SaveOutput which saves into a file at the given path.
Sourcepub fn stream<S: SaveStream + 'static>(stream: S) -> Self
pub fn stream<S: SaveStream + 'static>(stream: S) -> Self
Creates a new SaveOutput which saves into a Write stream.
Sourcepub fn consume(&mut self) -> Option<SaveOutput>
pub fn consume(&mut self) -> Option<SaveOutput>
Invalidates this SaveOutput and returns it if it was valid.