Struct moonshine_save::load::Unload
source · pub struct Unload;Expand description
A Component which marks its Entity to be despawned prior to load.
Usage
When saving game state, it is often undesirable to save visual and aesthetic elements of the game. Elements such as transforms, camera settings, scene hierarchy, or UI elements are typically either spawned at game start, or added during initialization of the game data they represent.
This component may be used on such entities to despawn them prior to loading.
Example
use bevy::prelude::*;
use moonshine_save::prelude::*;
#[derive(Bundle)]
struct PlayerBundle {
player: Player,
/* Saved Player Data */
save: Save,
}
#[derive(Component, Default, Reflect)]
#[reflect(Component)]
struct Player;
#[derive(Component)] // <-- Not serialized!
struct PlayerSprite(Entity);
#[derive(Bundle, Default)]
struct PlayerSpriteBundle {
/* Player Visuals/Aesthetics */
unload: Unload,
}
fn spawn_player_sprite(query: Query<Entity, Added<Player>>, mut commands: Commands) {
for entity in &query {
let sprite = PlayerSprite(commands.spawn(PlayerSpriteBundle::default()).id());
commands.entity(entity).insert(sprite);
}
}Trait Implementations
sourceimpl Component for Unload
impl Component for Unload
sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
sourcefn register_component_hooks(_hooks: &mut ComponentHooks)
fn register_component_hooks(_hooks: &mut ComponentHooks)
Called when registering this component, allowing mutable access to its
ComponentHooks.Auto Trait Implementations
impl Freeze for Unload
impl RefUnwindSafe for Unload
impl Send for Unload
impl Sync for Unload
impl Unpin for Unload
impl UnwindSafe for Unload